@@ -32,7 +32,7 @@ class ApemanModelServer(apemanOpenApi_pb2_grpc.ApemanModelOpenApiServicer):
 
 async def serve() -> None:
     server = grpc.aio.server()
-    apemanOpenApi_pb2_grpc.add_ApemanModelClientServicer_to_server(
+    apemanOpenApi_pb2_grpc.add_ApemanModelOpenApiServicer_to_server(
         ApemanModelServer(), server)
     server.add_insecure_port('[::]:9090')
     await server.start()
